@@ -50,7 +50,14 @@ class Instance(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Instance.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["InstanceProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -121,7 +128,23 @@ class InstanceProps:
         :param use_promotion_code: Property usePromotionCode: Whether to use coupons.The value is as follows: true: Use. false: Not in use.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(InstanceProps.__init__)
+            def stub(
+                *,
+                bucket: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                charge_type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                instance_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                vpc_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                v_switch_ids: typing.Union[typing.Sequence[typing.Any], ros_cdk_core.IResolvable],
+                zone_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                auto_renew: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                duration: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                pricing_cycle: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                promotion_code: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                resource_spec: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosInstance.ResourceSpecProperty", typing.Dict[str, typing.Any]]]] = None,
+                use_promotion_code: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
             check_type(argname="argument charge_type", value=charge_type, expected_type=type_hints["charge_type"])
             check_type(argname="argument instance_name", value=instance_name, expected_type=type_hints["instance_name"])
@@ -299,7 +322,14 @@ class Namespace(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Namespace.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["NamespaceProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -343,7 +373,14 @@ class NamespaceProps:
         :param resource_spec: Property resourceSpec: Resource specifications.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NamespaceProps.__init__)
+            def stub(
+                *,
+                instance_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                namespace: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                resource_spec: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosNamespace.ResourceSpecProperty", typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
             check_type(argname="argument namespace", value=namespace, expected_type=type_hints["namespace"])
             check_type(argname="argument resource_spec", value=resource_spec, expected_type=type_hints["resource_spec"])
@@ -410,7 +447,14 @@ class RosInstance(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosInstance.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosInstanceProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -426,7 +470,9 @@ class RosInstance(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosInstance._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -471,7 +517,11 @@ class RosInstance(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "bucket").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "bucket", value)
 
@@ -493,7 +543,11 @@ class RosInstance(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "charge_type").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "chargeType", value)
 
@@ -505,7 +559,9 @@ class RosInstance(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -523,7 +579,11 @@ class RosInstance(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "instance_name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "instanceName", value)
 
@@ -541,7 +601,11 @@ class RosInstance(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "vpc_id").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "vpcId", value)
 
@@ -561,7 +625,11 @@ class RosInstance(
         value: typing.Union[typing.List[typing.Any], ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "v_switch_ids").fset)
+            def stub(
+                value: typing.Union[typing.List[typing.Any], ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "vSwitchIds", value)
 
@@ -579,7 +647,11 @@ class RosInstance(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "zone_id").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "zoneId", value)
 
@@ -603,7 +675,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "auto_renew").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "autoRenew", value)
 
@@ -628,7 +704,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "duration").fset)
+            def stub(
+                value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "duration", value)
 
@@ -648,7 +728,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "pricing_cycle").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "pricingCycle", value)
 
@@ -668,7 +752,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "promotion_code").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "promotionCode", value)
 
@@ -691,7 +779,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosInstance.ResourceSpecProperty"]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "resource_spec").fset)
+            def stub(
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosInstance.ResourceSpecProperty"]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resourceSpec", value)
 
@@ -715,7 +807,11 @@ class RosInstance(
         value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstance, "use_promotion_code").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "usePromotionCode", value)
 
@@ -736,7 +832,13 @@ class RosInstance(
             :param memory_gb: 
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(RosInstance.ResourceSpecProperty.__init__)
+                def stub(
+                    *,
+                    cpu: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                    memory_gb: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument cpu", value=cpu, expected_type=type_hints["cpu"])
                 check_type(argname="argument memory_gb", value=memory_gb, expected_type=type_hints["memory_gb"])
             self._values: typing.Dict[str, typing.Any] = {}
@@ -831,7 +933,23 @@ class RosInstanceProps:
         :param use_promotion_code: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosInstanceProps.__init__)
+            def stub(
+                *,
+                bucket: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                charge_type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                instance_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                vpc_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                v_switch_ids: typing.Union[typing.Sequence[typing.Any], ros_cdk_core.IResolvable],
+                zone_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                auto_renew: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                duration: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                pricing_cycle: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                promotion_code: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                resource_spec: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosInstance.ResourceSpecProperty, typing.Dict[str, typing.Any]]]] = None,
+                use_promotion_code: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
             check_type(argname="argument charge_type", value=charge_type, expected_type=type_hints["charge_type"])
             check_type(argname="argument instance_name", value=instance_name, expected_type=type_hints["instance_name"])
@@ -1035,7 +1153,14 @@ class RosNamespace(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosNamespace.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosNamespaceProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -1051,7 +1176,9 @@ class RosNamespace(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosNamespace._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -1090,7 +1217,9 @@ class RosNamespace(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosNamespace, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -1108,7 +1237,11 @@ class RosNamespace(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosNamespace, "instance_id").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "instanceId", value)
 
@@ -1126,7 +1259,11 @@ class RosNamespace(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosNamespace, "namespace").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "namespace", value)
 
@@ -1146,7 +1283,11 @@ class RosNamespace(
         value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosNamespace.ResourceSpecProperty"]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosNamespace, "resource_spec").fset)
+            def stub(
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosNamespace.ResourceSpecProperty"]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resourceSpec", value)
 
@@ -1167,7 +1308,13 @@ class RosNamespace(
             :param memory_gb: 
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(RosNamespace.ResourceSpecProperty.__init__)
+                def stub(
+                    *,
+                    cpu: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                    memory_gb: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument cpu", value=cpu, expected_type=type_hints["cpu"])
                 check_type(argname="argument memory_gb", value=memory_gb, expected_type=type_hints["memory_gb"])
             self._values: typing.Dict[str, typing.Any] = {}
@@ -1240,7 +1387,14 @@ class RosNamespaceProps:
         :param resource_spec: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosNamespaceProps.__init__)
+            def stub(
+                *,
+                instance_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                namespace: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                resource_spec: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosNamespace.ResourceSpecProperty, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
             check_type(argname="argument namespace", value=namespace, expected_type=type_hints["namespace"])
             check_type(argname="argument resource_spec", value=resource_spec, expected_type=type_hints["resource_spec"])
