@@ -14,7 +14,10 @@ import constructs._jsii
 import ros_cdk_core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@alicloud/ros-cdk-flink", "1.0.9", __name__[0:-6], "ros-cdk-flink@1.0.9.jsii.tgz"
+    "@alicloud/ros-cdk-flink",
+    "1.0.10",
+    __name__[0:-6],
+    "ros-cdk-flink@1.0.10.jsii.tgz",
 )
 
 __all__ = [
